
	
	
	
(defun C:QTSW ();       Toggles QTEXTMODE
; by Roger S. Brooks, 4880 Galley Rd. #228, Colorado Springs, CO 80915
    (if (= 0 (getvar "QTEXTMODE"))
        (command "QTEXT" "ON")
        (command "QTEXT" "OFF")
    )
)
;
(defun C:BOX ();        Draws a box on current layer
; by Roger S. Brooks, 4880 Galley Rd. #228, Colorado Springs, CO 80915
; three specification modes are available:
;       <default>	two diagonally opposite corners
;       Side            center of one side, width and center of opposite side
    (setvar "CMDECHO" 0)
    (if (setq pt1 (getpoint "Side/<First corner>: "))
	(progn
	    (setq pt3 (getpoint "Second corner: "))
	    (setq pt2 (list (car pt1) (cadr pt3)))
	    (setq pt4 (list (car pt3) (cadr pt1)))
	)
	(progn
	    (setq pt0 (getpoint "Center of side: "))
	    (setq pt1 (getpoint "Center of opposite side: "))
	    (setq da (- (angle pt0 pt1) (/ pi 2)))
	    (setq dw (/ (getdist "Width of box: ") 2))
	    (setq pt2 (polar pt1 (- da) dw))
	    (setq pt3 (polar pt1 da dw))
	    (setq pt1 (polar pt0 (- da) dw))
	    (setq pt4 (polar pt0 da dw))
	)
    )
    (command "PLINE" pt1 pt2 pt3 pt4 "C")
    (quote Command: )
)
;
(defun C:CBOX ()
; draws a box on current layer given center and one corner
; by Roger S. Brooks, 4880 Galley Rd. #228, Colorado Springs, CO 80915
    (setvar "CMDECHO" 0)
    (setq pt0 (getpoint "Center of box: "))
    (setq pt1 (getpoint "Enter corner: "))
    (setq x3 (- (* 2 (car pt0)) (car pt1)))
    (setq y3 (- (* 2 (cadr pt0)) (cadr pt1)))
    (setq pt2 (list (car pt1) y3))
    (setq pt3 (list x3 y3))
    (setq pt4 (list x3 (cadr pt1)))
    (command "PLINE" pt1 pt2 pt3 pt4 "C")
    (quote Command: )
)
	
	
	
	
(defun C:BUBBLE ();	draws a numbered bubble with leader on layer 0
; by Roger S. Brooks, 4880 Galley Rd. #228, Colorado Springs, CO 80915
    (setvar "CMDECHO" 0)
    (command "LAYER" "S" "0")
    (setq dx (setq delta (getvar "TEXTSIZE")))
    (setq pt0 (getpoint "Object/<Start point>: "))
    (if pt0
	(progn
	    (setq pt1 (getpoint "Second point: "))
	    (setq dangle (angtos (angle pt0 pt1) 0 1))
	    (command "SHAPE" "SQUIGGLE" pt0 delta dangle)
	)
	(progn
	    (setq pt0 (getpoint "Boundary point: "))
	    (setq pt1 (getpoint "Second point: "))
	)
    )
    (command "DIM")
    (command "LEADER" pt0 pt1 "" "")
    (command)
    (setq x2 (car pt1))
    (setq y2 (cadr pt1))
    (if (>= (car pt0) x2) (setq dx (- dx)))
    (if (/= (cadr pt0) y2) (setq dx (* 2 dx)))
    (setq x2 (+ x2 dx))
    (setq pt2 (list x2 y2))
    (command "CIRCLE" pt2 delta)
    (setq txt (getstring "Bubble number: "))
    (setq pt2 (list x2 (- y2 (/ delta 2))))
    (command "TEXT" "C" pt2 delta 0 txt)
    (quote Command: )
)
;
(defun C:NOTES ();
; by Roger S. Brooks, 4880 Galley Rd. #228, Colorado Springs, CO 80915
    (setvar "CMDECHO" 0)
    (setq filename (getstring "Text file: "))
    (setq handle (open filename "r"))
    (if handle
	(progn
	    (setq mode (getvar "LUNITS"))
	    (setq prec (getvar "LUPREC"))
	    (setq size (rtos (getvar "TEXTSIZE") mode prec))
	    (setq str (strcat "Height <" size ">: "))
	    (setq pt (getpoint "Upper left corner: "))
	    (setq ht (getreal str))
	    (if (not ht) (setq ht (getvar "TEXTSIZE")))
	    (setq pt (list (car pt) (- (cadr pt) ht)))
	    (if (setq str (read-line handle))
		(progn
		    (setq line (/ ht 0.6))
		    (command "TEXT" pt ht 0 str)
		    (while (setq str (read-line handle))
			(setq pt (list (car pt) (- (cadr pt) line)))
			(command "TEXT" pt ht 0 str)
		    )
		)
		(write-line "File is empty.")
	    )
	    (close handle)
	)
	(write-line "No such file.")
    )
    (quote Command: )
)
